@@ -4,7 +4,7 @@ use Moose;
 use namespace::autoclean;
 
 # ABSTRACT: munge the AUTHOR section
-our $VERSION = '2.09'; # VERSION
+our $VERSION = '2.10'; # VERSION
 
 
 extends 'Dist::Zilla::Plugin::MakeMaker';
@@ -15,9 +15,9 @@ around write_makefile_args => sub {
   
   my $h = $self->$orig(@_);  
 
-  # to prevent any non .pm files from being installed in lib
+  # to prevent any non .pm/.pod files from being installed in lib
   # because shit like this is stuff we ought to have to customize.
-  my %PM = map {; "lib/$_" => "\$(INST_LIB)/$_" } map { s/^lib\///; $_ } grep /^lib\/.*\.pm$/, map { $_->name } @{ $self->zilla->files };
+  my %PM = map {; "lib/$_" => "\$(INST_LIB)/$_" } map { s/^lib\///; $_ } grep /^lib\/.*\.p(od|m)$/, map { $_->name } @{ $self->zilla->files };
   $h->{PM} = \%PM;
 
   $h;
@@ -39,7 +39,7 @@ Dist::Zilla::Plugin::Author::Plicease::MakeMaker - munge the AUTHOR section
 
 =head1 VERSION
 
-version 2.09
+version 2.10
 
 =head1 SYNOPSIS
 
