@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: Upload a dist to CPAN
-our $VERSION = '2.09'; # VERSION
+our $VERSION = '2.10'; # VERSION
 
 
 extends 'Dist::Zilla::Plugin::UploadToCPAN';
@@ -16,7 +16,7 @@ has cpan => (
 
 has scp_dest => (
   is      => 'ro',
-  default => sub { 'ollisg@matrix.wdlabs.com:web/sites/dist' },
+  default => sub { 'ollisg@ratbat.wdlabs.com:web/sites/dist' },
 );
 
 has url => (
@@ -86,7 +86,7 @@ Dist::Zilla::Plugin::Author::Plicease::Upload - Upload a dist to CPAN
 
 =head1 VERSION
 
-version 2.09
+version 2.10
 
 =head1 SYNOPSIS
 
